==> reakit-0.13.1.tgz: package/es/Overlay.js <==
import React from 'react';
import ReactDOM from 'react-dom';
import styled from 'styled-components';
import { prop } from 'styled-tools';
import { a as as, b as classCallCheck, c as inherits, d as objectWithoutProperties, e as possibleConstructorReturn, f as _extends } from './as-8a1cd76d.js';
import Hidden from './Hidden.js';
import { a as OverlayContainer, b as OverlayToggle, c as OverlayShow, d as OverlayHide } from './chunk-be7b3a82.js';
import 'lodash-es/uniq';
import 'react-known-props';
import 'lodash-es/omit';
import './chunk-84d8695a.js';
import 'prop-types';
import 'hoist-non-react-statics';
import './chunk-fa81e9f1.js';
import './Base.js';
import './chunk-a29c7f2d.js';
import 'lodash-es/kebabCase';
import './chunk-3cd03ec9.js';
import 'constate';
import './chunk-60576777.js';

var Component = function (_React$Component) {
  inherits(Component, _React$Component);

  function Component() {
    var _temp, _this, _ret;

    classCallCheck(this, Component);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = possibleConstructorReturn(this, _React$Component.call.apply(_React$Component, [this].concat(args))), _this), _this.state = {}, _temp), possibleConstructorReturn(_this, _ret);
  }

  Component.prototype.componentDidMount = function componentDidMount() {
    var wrapper = document.createElement("div");
    document.body.appendChild(wrapper);
    this.setState({ wrapper: wrapper });
  };

  Component.prototype.componentWillUnmount = function componentWillUnmount() {
    document.body.removeChild(this.state.wrapper);
  };

  Component.prototype.render = function render() {
    var wrapper = this.state.wrapper;

    if (wrapper) {
      return ReactDOM.createPortal(React.createElement(Hidden, this.props), wrapper);
    }
    return null;
  };

  return Component;
}(React.Component);

var Overlay = styled(Component).withConfig({
  displayName: "Overlay"
})(["position:fixed;background-color:white;left:50%;top:50%;z-index:19900410;", ";"], prop("theme.Overlay"));

Overlay.defaultProps = {
  role: "dialog",
  "aria-modal": true,
  hideOnEsc: true,
  translateX: "-50%",
  translateY: "-50%",
  defaultSlide: "top"
};

var Overlay$1 = as("div")(Overlay);

Overlay$1.Container = OverlayContainer;
Overlay$1.Toggle = OverlayToggle;
Overlay$1.Show = OverlayShow;
Overlay$1.Hide = OverlayHide;

export default Overlay$1;

==> reakit-0.13.2.tgz: package/es/Overlay.js <==
import React from 'react';
import ReactDOM from 'react-dom';
import styled from 'styled-components';
import { prop } from 'styled-tools';
import { a as as, b as classCallCheck, c as inherits, d as objectWithoutProperties, e as possibleConstructorReturn, f as _extends } from './as-fe550043.js';
import Hidden from './Hidden.js';
import { a as OverlayContainer, b as OverlayToggle, c as OverlayShow, d as OverlayHide } from './chunk-c31e54ec.js';
import 'lodash-es/uniq';
import 'react-known-props';
import 'lodash-es/omit';
import './chunk-84d8695a.js';
import 'prop-types';
import 'hoist-non-react-statics';
import './chunk-fa81e9f1.js';
import './Base.js';
import './chunk-a29c7f2d.js';
import 'lodash-es/kebabCase';
import './chunk-10d4a0a3.js';
import 'constate';
import './chunk-5093c559.js';

var Component = function (_React$Component) {
  inherits(Component, _React$Component);

  function Component() {
    var _temp, _this, _ret;

    classCallCheck(this, Component);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = possibleConstructorReturn(this, _React$Component.call.apply(_React$Component, [this].concat(args))), _this), _this.state = { wrapper: null }, _temp), possibleConstructorReturn(_this, _ret);
  }

  Component.prototype.componentDidMount = function componentDidMount() {
    var wrapper = document.createElement("div");
    document.body.appendChild(wrapper);
    this.setState({ wrapper: wrapper });
  };

  Component.prototype.componentWillUnmount = function componentWillUnmount() {
    if (this.state.wrapper) {
      document.body.removeChild(this.state.wrapper);
    }
  };

  Component.prototype.render = function render() {
    var wrapper = this.state.wrapper;

    if (wrapper) {
      return ReactDOM.createPortal(React.createElement(Hidden, this.props), wrapper);
    }
    return null;
  };

  return Component;
}(React.Component);

var Overlay = styled(Component).withConfig({
  displayName: "Overlay"
})(["position:fixed;background-color:white;left:50%;top:50%;z-index:19900410;", ";"], prop("theme.Overlay"));

Overlay.defaultProps = {
  role: "dialog",
  "aria-modal": true,
  hideOnEsc: true,
  translateX: "-50%",
  translateY: "-50%",
  defaultSlide: "top"
};

var Overlay$1 = as("div")(Overlay);

Overlay$1.Container = OverlayContainer;
Overlay$1.Toggle = OverlayToggle;
Overlay$1.Show = OverlayShow;
Overlay$1.Hide = OverlayHide;

export default Overlay$1;
